==> kadaster-gds2-1.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/v20130701/BestandOphalenResultaatType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701.AfgifteBestandType;
import nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922.ProcesVerwerking;


/**
 * Het opgehaalde bestand, behorende bij de opgegeven
 * 				afgifte identificatie. Indien de afgifte identificatie bekend is,
 * 				dan is er altijd een bestand aanwezig. Zo niet, dan wordt een
 * 				functionele foutmelding gegeven, waarin het afgifte identificatie
 * 				wordt teruggekoppeld.
 * 
 * <p>Java class for BestandOphalenResultaatType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandOphalenResultaatType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerking"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701}AfgifteBestand" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandOphalenResultaatType", propOrder = {
    "procesVerwerking",
    "afgifteBestand"
})
public class BestandOphalenResultaatType {

    @XmlElement(name = "ProcesVerwerking", namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", required = true)
    protected ProcesVerwerking procesVerwerking;
    @XmlElement(name = "AfgifteBestand", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701")
    protected AfgifteBestandType afgifteBestand;

    /**
     * Gets the value of the procesVerwerking property.
     * 
     * @return
     *     possible object is
     *     {@link ProcesVerwerking }
     *     
     */
    public ProcesVerwerking getProcesVerwerking() {
        return procesVerwerking;
    }

    /**
     * Sets the value of the procesVerwerking property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProcesVerwerking }
     *     
     */
    public void setProcesVerwerking(ProcesVerwerking value) {
        this.procesVerwerking = value;
    }

    /**
     * Gets the value of the afgifteBestand property.
     * 
     * @return
     *     possible object is
     *     {@link AfgifteBestandType }
     *     
     */
    public AfgifteBestandType getAfgifteBestand() {
        return afgifteBestand;
    }

    /**
     * Sets the value of the afgifteBestand property.
     * 
     * @param value
     *     allowed object is
     *     {@link AfgifteBestandType }
     *     
     */
    public void setAfgifteBestand(AfgifteBestandType value) {
        this.afgifteBestand = value;
    }

}

==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/v20130701/BestandOphalenResultaatType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701.AfgifteBestandType;
import nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922.ProcesVerwerking;


/**
 * Het opgehaalde bestand, behorende bij de opgegeven
 * 				afgifte identificatie. Indien de afgifte identificatie bekend is,
 * 				dan is er altijd een bestand aanwezig. Zo niet, dan wordt een
 * 				functionele foutmelding gegeven, waarin het afgifte identificatie
 * 				wordt teruggekoppeld.
 * 
 * &lt;p&gt;Java class for BestandOphalenResultaatType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="BestandOphalenResultaatType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerking"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701}AfgifteBestand" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandOphalenResultaatType", propOrder = {
    "procesVerwerking",
    "afgifteBestand"
})
public class BestandOphalenResultaatType {

    @XmlElement(name = "ProcesVerwerking", namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", required = true)
    protected ProcesVerwerking procesVerwerking;
    @XmlElement(name = "AfgifteBestand", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701")
    protected AfgifteBestandType afgifteBestand;

    /**
     * Gets the value of the procesVerwerking property.
     * 
     * @return
     *     possible object is
     *     {@link ProcesVerwerking }
     *     
     */
    public ProcesVerwerking getProcesVerwerking() {
        return procesVerwerking;
    }

    /**
     * Sets the value of the procesVerwerking property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProcesVerwerking }
     *     
     */
    public void setProcesVerwerking(ProcesVerwerking value) {
        this.procesVerwerking = value;
    }

    /**
     * Gets the value of the afgifteBestand property.
     * 
     * @return
     *     possible object is
     *     {@link AfgifteBestandType }
     *     
     */
    public AfgifteBestandType getAfgifteBestand() {
        return afgifteBestand;
    }

    /**
     * Sets the value of the afgifteBestand property.
     * 
     * @param value
     *     allowed object is
     *     {@link AfgifteBestandType }
     *     
     */
    public void setAfgifteBestand(AfgifteBestandType value) {
        this.afgifteBestand = value;
    }

}
